==> satellite-system-10.3.10-sources.jar: com/xebialabs/deployit/plugin/satellite/SatelliteInfoChecker.scala <==
/**
  * Copyright 2014-2019 XebiaLabs Inc. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
  */
package com.xebialabs.deployit.plugin.satellite

import akka.actor.{Actor, ActorRef, ActorSelection, Props, ReceiveTimeout}
import com.xebialabs.deployit.engine.api.dto.SatelliteInfo
import com.xebialabs.deployit.plugin.satellite.SatelliteInfoChecker.Get
import com.xebialabs.satellite.protocol.{GetSatelliteInfo, SatelliteInfoReply}
import com.xebialabs.xlplatform.settings.CommonSettings
import grizzled.slf4j.Logging

object SatelliteInfoChecker {
  def props(satelliteAddress: String) = Props(new SatelliteInfoChecker(satelliteAddress))

  case class Get(target: ActorSelection)

}

class SatelliteInfoChecker(satelliteAddress: String) extends Actor with Logging {
  def receive = waitingForInfo

  private def waitingForInfo: Receive = {
    case Get(target) =>
      if (!CommonSettings(context.system).satellite.enabled) {
        logger.debug(s"Satellite $satelliteAddress is not enabled")
        sender() ! new SatelliteInfo()
        context stop self
      } else {
        target ! GetSatelliteInfo
        context become (waitingForReply(sender) orElse handleTimeout(sender))
      }
  }

  private def waitingForReply(origin: ActorRef): Receive = {
    case SatelliteInfoReply(info) =>
      origin ! info
      context become waitingForInfo
      context stop self
  }

  private def handleTimeout(origin: ActorRef): Receive = {
    case ReceiveTimeout =>
      logger.debug(s"The satellite $satelliteAddress cannot be reached. Please check whether it is running.")
      origin ! new SatelliteInfo()
      context stop self
  }

}

==> satellite-system-25.1.0-324.113-sources.jar: com/xebialabs/deployit/plugin/satellite/SatelliteInfoChecker.scala <==
/**
  * Copyright 2014-2019 XebiaLabs Inc. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
  */
package com.xebialabs.deployit.plugin.satellite

import com.xebialabs.deployit.engine.api.dto.SatelliteInfo
import com.xebialabs.deployit.plugin.satellite.SatelliteInfoChecker.Get
import com.xebialabs.satellite.protocol.{GetSatelliteInfo, SatelliteInfoReply}
import com.xebialabs.xlplatform.settings.CommonSettings
import grizzled.slf4j.Logging
import org.apache.pekko.actor.{Actor, ActorRef, ActorSelection, Props, ReceiveTimeout}

object SatelliteInfoChecker {
  def props(satelliteAddress: String) = Props(new SatelliteInfoChecker(satelliteAddress))

  case class Get(target: ActorSelection)

}

class SatelliteInfoChecker(satelliteAddress: String) extends Actor with Logging {
  def receive = waitingForInfo

  private def waitingForInfo: Receive = {
    case Get(target) =>
      if (!CommonSettings(context.system).satellite.enabled) {
        logger.debug(s"Satellite $satelliteAddress is not enabled")
        sender() ! new SatelliteInfo()
        context stop self
      } else {
        target ! GetSatelliteInfo
        context become (waitingForReply(sender) orElse handleTimeout(sender))
      }
  }

  private def waitingForReply(origin: ActorRef): Receive = {
    case SatelliteInfoReply(info) =>
      origin ! info
      context become waitingForInfo
      context stop self
  }

  private def handleTimeout(origin: ActorRef): Receive = {
    case ReceiveTimeout =>
      logger.debug(s"The satellite $satelliteAddress cannot be reached. Please check whether it is running.")
      origin ! new SatelliteInfo()
      context stop self
  }

}
